@@ -34,7 +34,7 @@
 #include "vstr.h"
 #include "config.h"
 
-static char gp_title[] = "dvdspanky 1.0.8 - (c) 2007 Jeffrey Grembecki\n\n";
+static char gp_title[] = "dvdspanky 1.0.9 - (c) 2007 Jeffrey Grembecki\n\n";
 static char gp_licence[] =
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -516,7 +516,7 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 		if(options & SPANK_SPEED)
 		{
 			print(ML_INFO, NULL, "changing audio speed..");
-			if(forkitf(cb_sox, NULL, SOX_BIN, "sox\n-S\n%s_.wav\n%s.wav\nspeed\n%.9f",
+			if(forkitf(cb_sox, NULL, SOX_BIN, "sox\n-S\n-t\nwav\n%s_.wav\n-t\nwav\n%s.wav\nspeed\n%.9f",
 				p_out->p_filename, p_out->p_filename, p_out->fps / p_in->fps))
 			{
 				print(ML_INFO, NULL, "");
