@@ -110,24 +110,6 @@ int vs_print(vstr *p_vs, const char *p_format, ...)
 	return length;
 }
 
-/*
-int vs_vprint(vstr *p_vs, const char *p_format, va_list list)
-{
-	int length;
-
-	length = vsnprintf(NULL, 0, p_format, list);
-
-	if(vs_realloc(p_vs, length))
-		return -1;
-
-	vsprintf(p_vs->s, p_format, list);
-
-	p_vs->len = length;
-
-	return length;
-}
-*/
-
 int vs_cat(vstr *p_vs, const char *p_format, ...)
 {
 	int length;
@@ -149,24 +131,6 @@ int vs_cat(vstr *p_vs, const char *p_format, ...)
 	return length;
 }
 
-/*
-int vs_vcat(vstr *p_vs, const char *p_format, va_list list)
-{
-	int length;
-
-	length = vsnprintf(NULL, 0, p_format, list) + p_vs->len;
-
-	if(vs_realloc(p_vs, length))
-		return -1;
-
-	vsprintf(&p_vs->s[p_vs->len], p_format, list);
-
-	p_vs->len = length;
-
-	return length;
-}
-*/
-
 int vs_copy(vstr *p_dest, vstr *p_source)
 {
 	char *p_s;
